@@ -7,15 +7,15 @@ from .icommand import ICommand
 from .icommand_handler import ICommandHandler
 from .iquery import IQuery
 from .iquery_handler import IQueryHandler
+from ..dependency import IScoped
 from ..dependency.provider import ServiceProvider
-from ..dependency.scopes import IScoped
 
 T = TypeVar('T', covariant=True)
 
 
 class Dispatcher(IScoped):
     @inject
-    def __init__(self,service_provider:ServiceProvider):
+    def __init__(self, service_provider: ServiceProvider):
         self.service_provider = service_provider
 
     def find_handler(self, type, handler_type: Type[T]) -> T:
